@@ -24,19 +24,6 @@
 //! [zstd]: https://github.com/facebook/zstd
 #![deny(missing_docs)]
 
-#[cfg(test)]
-extern crate partial_io;
-
-extern crate zstd_safe;
-
-#[cfg(feature = "tokio")]
-#[macro_use]
-extern crate tokio_io;
-#[cfg(feature = "tokio")]
-extern crate futures;
-#[cfg(all(test, feature = "tokio"))]
-extern crate quickcheck;
-
 pub mod block;
 pub mod dict;
 pub mod stream;
@@ -47,7 +34,7 @@ use std::io;
 pub use zstd_safe::CLEVEL_DEFAULT as DEFAULT_COMPRESSION_LEVEL;
 
 #[doc(no_inline)]
-pub use stream::{decode_all, encode_all, Decoder, Encoder};
+pub use crate::stream::{decode_all, encode_all, Decoder, Encoder};
 
 /// Returns the error message as io::Error based on error_code.
 fn map_error_code(code: usize) -> io::Error {
